from distutils.core import setup

setup(
  name = 'pinuccio',         # How you named your package folder (MyLib)
  packages = ['pinuccio'],   # Chose the same as "name"
  version = '0.0.2',      # Start with a small number and increase it with every change you make
  install_requires=[]
)